@@ -245,7 +245,8 @@ slide_vec_direct <- function(.x,
                              .after,
                              .step,
                              .complete,
-                             .ptype) {
+                             .ptype,
+                             .slider_error_call = caller_env()) {
   slide_impl(
     .x,
     .f,
@@ -256,7 +257,8 @@ slide_vec_direct <- function(.x,
     .complete = .complete,
     .ptype = .ptype,
     .constrain = TRUE,
-    .atomic = TRUE
+    .atomic = TRUE,
+    .slider_error_call = .slider_error_call
   )
 }
 
@@ -405,10 +407,11 @@ slide_impl <- function(.x,
                        .complete,
                        .ptype,
                        .constrain,
-                       .atomic) {
-  vec_assert(.x)
+                       .atomic,
+                       .slider_error_call = caller_env()) {
+  vec_assert(.x, call = .slider_error_call)
 
-  .f <- as_function(.f)
+  .f <- as_function(.f, call = .slider_error_call)
 
   f_call <- expr(.f(.x, ...))
 
