@@ -44,20 +44,11 @@
 #define SLIDE_LOOP_ATOMIC(CTYPE, DEREF, ASSIGN_ONE) do { \
   CTYPE* p_out = DEREF(out);                             \
   SLIDE_LOOP(ASSIGN_ONE);                                \
-} while (0)                                              \
+} while (0)
 
-#define SLIDE_LOOP_BARRIER(ASSIGN_ONE) do {                    \
-  SEXP p_out = out;                                            \
-                                                               \
-  /* Initialize with `NA`, not `NULL` */                       \
-  /* for size stability when auto-simplifying */               \
-  if (atomic && !constrain) {                                  \
-    for (R_len_t i = 0; i < size; ++i) {                       \
-      SET_VECTOR_ELT(p_out, i, slider_shared_na_lgl);          \
-    }                                                          \
-  }                                                            \
-                                                               \
-  SLIDE_LOOP(ASSIGN_ONE);                                      \
+#define SLIDE_LOOP_BARRIER(ASSIGN_ONE) do { \
+  SEXP p_out = out;                         \
+  SLIDE_LOOP(ASSIGN_ONE);                   \
 } while (0)
 
 // -----------------------------------------------------------------------------
@@ -113,11 +104,16 @@ SEXP slide_common_impl(SEXP x,
   SEXPTYPE out_type = TYPEOF(ptype);
   SEXP out = PROTECT(slider_init(out_type, size));
 
+  if (atomic && !constrain && out_type == VECSXP) {
+    // Initialize with `NA`, not `NULL`, for size stability when auto simplifying
+    list_fill(out, slider_shared_na_lgl);
+  }
+
   switch (out_type) {
   case INTSXP:  SLIDE_LOOP_ATOMIC(int, INTEGER, assign_one_int); break;
   case REALSXP: SLIDE_LOOP_ATOMIC(double, REAL, assign_one_dbl); break;
   case LGLSXP:  SLIDE_LOOP_ATOMIC(int, LOGICAL, assign_one_lgl); break;
-  case STRSXP:  SLIDE_LOOP_ATOMIC(SEXP, STRING_PTR, assign_one_chr); break;
+  case STRSXP:  SLIDE_LOOP_BARRIER(assign_one_chr); break;
   case VECSXP:  SLIDE_LOOP_BARRIER(assign_one_lst); break;
   default:      never_reached("slide_common_impl");
   }
