@@ -6,8 +6,8 @@
 #include "align.h"
 
 // From `summary-core-align.hpp`
-size_t align_of_long_double();
-size_t align_of_mean_state_t();
+size_t align_of_long_double(void);
+size_t align_of_mean_state_t(void);
 
 // -----------------------------------------------------------------------------
 // Sum
