@@ -20,6 +20,8 @@ test_that("can't access non-existant `.x` with empty `.l` and `.i`, but size `n
 })
 
 test_that("empty `.l` and `.i`, but size `n > 0` `.starts` and `.stops`: sizes and types are checked first", {
-  expect_error(phop_index(list(), integer(), 1:3, 1:2, ~.x), class = "vctrs_error_incompatible_size")
-  expect_error(phop_index(list(), integer(), 1, "x", ~.x), class = "vctrs_error_incompatible_type")
+  expect_snapshot({
+    (expect_error(phop_index(list(), integer(), 1:3, 1:2, ~.x), class = "vctrs_error_incompatible_size"))
+    (expect_error(phop_index(list(), integer(), 1, "x", ~.x), class = "vctrs_error_incompatible_type"))
+  })
 })
